//+------------------------------------------------------------------+
//|                                                     RSI_LiDo.mq4 |
//|                      Copyright  2004, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//| original "RSI_dot" concept by Accrete, and nicely tweaked by     |
//| telsa of ForexFactory fame !! Many thanks telsa...Accrete        |
//+------------------------------------------------------------------+
#property copyright "Copyright  2004, MetaQuotes Software Corp."
#property link      "http://www.metaquotes.net/"

#property indicator_separate_window
#property indicator_minimum 0
#property indicator_maximum 100
#property indicator_buffers 2
#property indicator_color1  DodgerBlue
#property indicator_color2  Lime




//---- input parameters
extern int    RSIPeriod       = 4;
extern double InpLiDoUPLine   = 75; //UP Line Alert
extern double InpLiDoDOWNLine = 25; //DOWN Line Alert
extern bool   alertsOn        = true;
extern bool   alertsOnCurrent = true;
extern bool   alertsMessage   = true;
extern bool   alertsSound     = true;
extern bool   alertsNotify    = false;
extern bool   alertsEmail     = false;
extern string soundfile       = "alert2.wav";

extern bool   ShowArrows      = true;
extern string arrowsIdentifier= "RSI_LiDo Arrows1";
extern color  arrowsUpColor   = LimeGreen;
extern color  arrowsDnColor   = Red;
//---- buffers
double dRsiLine[];
double dRsiDots[];
double trend[];

int init() 
{
    IndicatorBuffers(3);
    SetIndexBuffer(0,dRsiLine);                                                      SetIndexLabel (0,"RSI");
    SetIndexBuffer(1,dRsiDots); SetIndexStyle (1,DRAW_ARROW); SetIndexArrow (1,159); SetIndexLabel (1,"RSI");
    SetIndexBuffer(2,trend);
    SetLevelValue(0,InpLiDoUPLine);
    SetLevelValue(1,InpLiDoDOWNLine);
    IndicatorShortName("RSI LiDo (" + RSIPeriod + ")");
return(0);
}
int deinit() 
{ 
   deleteArrows();
return(0); 
}

//
//
//
//
//

int start() 
{
    int counted_bars=IndicatorCounted();
    if(counted_bars<0) return(-1);
    if(counted_bars>0) counted_bars--;
         int limit = MathMin(Bars-counted_bars,Bars-1);
    
    //
    //
    //
    //
    //
    
    for (int i=limit; i >= 0; i--)
    {  
        dRsiLine[i] = iRSI(NULL,0,RSIPeriod,PRICE_CLOSE,i);
        dRsiDots[i] = dRsiLine[i];
        
        //
        //
        //
        //
        //
        
        trend[i] = 0;
           if (dRsiLine[i]>InpLiDoUPLine)   trend[i] = 1;
           if (dRsiLine[i]<InpLiDoDOWNLine) trend[i] =-1;  
           
           //
           //
           //
           //
           //
           
           if (ShowArrows)
           {
             deleteArrow(Time[i]);
             if (trend[i]!=trend[i+1])
             {
               if (trend[i+1] ==  1 && trend[i] != 1) drawArrow(i,arrowsDnColor,226,true);
               if (trend[i+1] == -1 && trend[i] !=-1) drawArrow(i,arrowsUpColor,225,false);
             }
           }
    }
    
    //
    //
    //
    //
    //
    
    if (alertsOn)
    {
      if (alertsOnCurrent)
           int whichBar = 0;
      else     whichBar = 1;
      if (trend[whichBar] != trend[whichBar+1])
      {
         if (trend[whichBar+1] ==  1 && trend[whichBar] != 1) doAlert(whichBar,"leaving overbought");
         if (trend[whichBar+1] == -1 && trend[whichBar] !=-1) doAlert(whichBar,"leaving oversold");
      }         
    }
return(0);
}

//
//
//
//
//

void doAlert(int forBar, string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
   if (previousAlert != doWhat || previousTime != Time[forBar]) {
       previousAlert  = doWhat;
       previousTime   = Time[forBar];

       //
       //
       //
       //
       //

       message =  StringConcatenate(Symbol()," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," RSI_LiDo "+doWhat);
          if (alertsMessage) Alert(message);
          if (alertsNotify)  SendNotification(message);
          if (alertsEmail)   SendMail(StringConcatenate(Symbol()," RSI_LiDo "),message);
          if (alertsSound)   PlaySound(soundfile);
   }
}

//
//
//
//
//

void drawArrow(int i,color theColor,int theCode,bool up)
{
   string name = arrowsIdentifier+":"+Time[i];
   double gap  = 3.0*iATR(NULL,0,20,i)/4.0;   
   
      //
      //
      //
      //
      //
      
      ObjectCreate(name,OBJ_ARROW,0,Time[i],0);
         ObjectSet(name,OBJPROP_ARROWCODE,theCode);
         ObjectSet(name,OBJPROP_COLOR,theColor);
         if (up)
               ObjectSet(name,OBJPROP_PRICE1,High[i]+ gap);
         else  ObjectSet(name,OBJPROP_PRICE1,Low[i] - gap);
}

//
//
//
//
//

void deleteArrows()
{
   string lookFor       = arrowsIdentifier+":";
   int    lookForLength = StringLen(lookFor);
   for (int i=ObjectsTotal()-1; i>=0; i--)
   {
      string objectName = ObjectName(i);
         if (StringSubstr(objectName,0,lookForLength) == lookFor) ObjectDelete(objectName);
   }
}

//
//
//
//
//

void deleteArrow(datetime time)
{
   string lookFor = arrowsIdentifier+":"+time; ObjectDelete(lookFor);
}





